LogFile
==============

.. currentmodule:: biskit

.. autoclass:: LogFile
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~LogFile.__init__
      ~LogFile.add
      ~LogFile.add_nobreak
      ~LogFile.f
      ~LogFile.write
      ~LogFile.writeln
   
   

   
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>LogFile Method & Attribute Details</h2>

   
   